﻿<!-- This style sheet is provided by Eurosoft 'as is' as an example of the functionality
     that can be achieved. This file is not directly supported by Eurosoft.
     Copyright © 2013, Eurosoft (UK) Ltd. All Rights Reserved.-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">  

  <xsl:template match="/">
    <html>
      <style>
        <!--Standard Div and Title format styles-->
        div
        {
        margin: 0;
        padding: 0;
        width: 100%;
        }

        .title
        {
        font-family: Tahoma, Verdana, Helvetica;
        font-size: 1.5em;
        font-weight: bold;
        text-align: center;
        margin: 0;
        padding: 0;
        }

        body
        {
        background-color: #ffffff;
        }

        p
        {
        font-family: Tahoma, Verdana, Helvetica;
        font-size: 0.75em;
        margin: 0.75em 0;
        padding: 0;
        }

        .PaddingDiv
        {
        border: 1px solid #FFFFFF;
        }

        <!-- Test Div format styles -->
        div.Started
        {
        background-color: #C0E7F1;
        border: 1px solid #000;
        }

        div.Passed
        {
        background-color: #00C800;
        border: 1px solid #000;
        }

        div.Failed
        {
        background-color: #FF3232;
        border: 1px solid #000;
        }

        div.UserEnded
        {
        background-color: #FF6464;
        border: 1px solid #000;
        }

        div.NotAvail
        {
        background-color: #C0C0C0;
        border: 1px solid #000;
        }

        <!-- Cell div format styles-->
        .Result
        {
        width:150px;
        float:left;
        border: 1px solid #000;
        border-style: none solid none none;
        }

        .Test
        {
        width:100px;
        float:left;
        border: 1px solid #000;
        border-style: none solid none none;
        }

        .Lap
        {
        width:30px;
        float:left;
        border: 1px solid #000;
        border-style: none solid none none;
        }

        .Time
        {
        width:75px;
        float:left;
        border: 1px solid #000;
        border-style: none solid none none;
        }

        .Date
        {
        width:100px;
        float:left;
        border: 1px solid #000;
        border-style: none solid none none;
        }

        .Name
        {
        width:200px;
        float:left;
        border: 1px solid #000;
        border-style: none solid none none;
        }

        .ECode
        {
        width:100px;
        float:left;
        border-style: none;
        }

      </style>
<!-- ====================================================================================== -->
<!-- ACTUAL PAGE STARTS HERE-->
      <head>
        <title>QA+Win Test Results</title>
      </head>
      <body>
        <div id="document">          
          <!-- apply the template handler for the EuroLog tag. This writes all
               the results into the table-->
          <xsl:apply-templates select="/EuroLog"/>
        </div>
      </body>
    </html>
<!-- END OF PAGE-->
<!-- ====================================================================================== -->
  </xsl:template>



  <!-- =========================================== -->
  <!-- Template: EuroLog -->
  <!-- This template writes each of the Log entry
       rows into the table, but ignores STARTED.-->
  <!-- =========================================== -->
  <xsl:template match="/EuroLog">
    <!-- Create the page title-->
    <p class="title">
      QA+Win Test Results <xsl:value-of select="@Version"/>
    </p>
    <!-- Create headings for the table-->
    <div>
      <div class="Result" style="border: 0px">Result</div>
      <div class="Test" style="border: 0px">Test</div>
      <div class="Lap" style="border: 0px">Lap</div>
      <div class="Date" style="border: 0px">Date</div>
      <div class="Time" style="border: 0px">Time</div>
      <div class="Name" style="border: 0px">Name</div>
      <div class="ECode" style="border: 0px">Error Code</div>
    </div>
    
    <!-- Create the table content-->
    <xsl:for-each  select="LogEvent">
      <!--Process each log event entry-->
      <xsl:if test="@message != 2">
        <div class="PaddingDiv">
          <!-- Use the LogEvent template to write the results-->
          <xsl:call-template name="LogEvent" />
        </div>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>


  <!-- =========================================== -->
  <!-- Template: LogEvent -->
  <!-- This template writes the current LogEvent tag entry
       into the table. This function chooses the format
       based on the message type first.-->
  <!-- =========================================== -->
  <xsl:template name="LogEvent">    
    <!-- Check for each message type we can handle-->
    <xsl:if test="@message = 3">
      <!--PASSED message-->
      <xsl:call-template name="WriteTableEntry">
        <xsl:with-param name="ResultTemplate">Passed</xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    
    <xsl:if test="(@message = 6) or (@message = 4)">
      <!--ABORTED or SKIPPED message-->
      <xsl:call-template name="WriteTableEntry">
        <xsl:with-param name="ResultTemplate">UserEnded</xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    
    <xsl:if test="@message = 5">
      <!--FAILED message-->
      <xsl:call-template name="WriteTableEntry">
        <xsl:with-param name="ResultTemplate">Failed</xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    
    <xsl:if test="@message = 7">
      <!--NOT AVAILABLE message-->
      <xsl:call-template name="WriteTableEntry">
        <xsl:with-param name="ResultTemplate">NotAvail</xsl:with-param>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>


  <!-- =========================================== -->
  <!-- Template: WriteTableEntry -->
  <!-- This template writes the content of the table row
       for the current LogEvent entry using the template
       class supplied.-->
  <!-- =========================================== -->
  <xsl:template name ="WriteTableEntry">
    <!-- This param value is overwritten by the call template with param -->
    <xsl:param name="ResultTemplate">Passed</xsl:param>
    <!-- Date example: 2013-04-24T14:08:18+01:00-->
    <!-- Therefor the date is everything before the 'T'-->
    <xsl:variable name="Date" select="substring-before(@datetime, 'T')"/>
    <!-- The time is the string between the 'T' and the '+'-->
    <xsl:variable name="Time" select="substring(@datetime, 
                                      (string-length($Date) + 2), 
                                      (string-length(substring-before(@datetime, '+')) - (string-length($Date) + 1)))" />
    <!-- Description Example: NOT AVAILABLE - 0x00/3FF-0047 - 0000000000000000 -->
    <!-- The Result is the string before the first '-'. If there is no - then
          use the whole string as there is no error code.-->
    <xsl:variable name="Result">
     <xsl:choose>
      <xsl:when test="contains(@description, '-')">
        <xsl:value-of select="substring-before(@description, '-')"/>
      </xsl:when>
      <xsl:otherwise>
      <!-- This is a workaround for Skipped and Aborted results having no extra information.
      		This may change in future versions. -->
        <xsl:value-of select="@description"/> 
     </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>

    <div class="{$ResultTemplate}">
      <!-- Write the result using the variable above -->
      <div class="Result">
        <xsl:value-of select="$Result"/>
      </div>
      <!-- Write the test in the format "Group-Device-Test" using the attributes from the tag-->
      <div class="Test">
        <xsl:value-of select="@group"/> - <xsl:value-of select="@device"/> - <xsl:value-of select="@test"/>
      </div>
      <!-- Write the test lap using the lapcount-->
      <div class="Lap">
        <xsl:value-of select="@lapcount"/>
      </div>
      <!-- Write the date using the variable above-->
      <div class="Date">
        <xsl:value-of select="$Date"/>
      </div>
      <!-- Write the time using the variable above-->
      <div class="Time">
        <xsl:value-of select="$Time"/>
      </div>
      <!-- The testname attribute is option. check it exists before writing.-->
      <div class="Name">
        <xsl:if test ="string-length(@testname) > 0">
          <xsl:value-of select="@testname"/>
        </xsl:if>
      </div>
      <!-- Check that a '/' exists in the description, indicating the presence of an error code-->
      <div class="ECode">
        <xsl:if test="contains(@description, '/')">
          <!-- The error code always has a fixed length. Find the start of the code and write it.-->
          <xsl:variable name="ECode" select="substring(@description, string-length(substring-before(@description, '-')) + 2, 14)"/>
          <xsl:value-of select="$ECode"/>
        </xsl:if>
      </div>
    </div>
    
  </xsl:template>
</xsl:stylesheet>