<!-- This style sheet is provided by Eurosoft 'as is' as an example of the functionality
     that can be achieved. This file is not directly supported by Eurosoft.
     Copyright © 2013, Eurosoft (UK) Ltd. All Rights Reserved.-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:template match="/">
    <html>
      <style>
        <!--Standard Div and Title format styles-->
        div
        {
        margin: 0;
        padding: 0;
        width: 100%;
        }

        .title
        {
        font-family: Tahoma, Verdana, Helvetica;
        font-size: 1.5em;
        font-weight: bold;
        text-align: center;
        margin: 0;
        padding: 0;
        }

        body
        {
        background-color: #ffffff;
        }

        p
        {
        font-family: Tahoma, Verdana, Helvetica;
        font-size: 0.75em;
        margin: 0.75em 0;
        padding: 0;
        }

        .PaddingDiv
        {
        border: 1px solid #FFFFFF;
        }

        .DeviceDiv
        {
        border: 1px solid #888888;
        }

        <!-- Cell div format styles-->
        .Group
        {
        width:80px;
        float:left;
        border: 1px solid #000;
        border-style: none none none none;
        }

        .SubDevice
        {
        width:110px;
        float:left;
        border: 1px solid #000;
        border-style: none none none none;
        }

        .AttribName
        {
        width:300px;
        float:left;
        border: 1px solid #000;
        border-style: none none none none;
        }

        .AttribID
        {
        width:100px;
        float:left;
        border: 1px solid #000;
        border-style: none none none none;
        }

        .AttribValue
        {
        width:350px;
        float:left;
        border: 1px solid #000;
        border-style: none none none none;
        }

      </style>
      <!-- ====================================================================================== -->
      <!-- ACTUAL PAGE STARTS HERE-->
      <head>
        <title>QA+Win System Profile</title>
      </head>
      <body>
        <div id="document" style="width:1000px">
          <!-- Create the page title-->
          <p class="title">
            System Profile
          </p>
          <!-- Create headings for the table. This is for page layout-->
          <div>
            <div class="Group" style="border: 0px"></div>
            <div class="SubDevice" style="border: 0px"></div>
            <div class="AttribName" style="border: 0px"></div>
            <div class="AttribID" style="border: 0px"></div>
            <div class="AttribValue" style="border: 0px"></div>
          </div>
          <!-- apply the template handler for all tags inside the system profile tags.-->
          <xsl:for-each select="SystemProfile/*">
            <xsl:call-template name="GroupTag"/>
          </xsl:for-each>
        </div>
      </body>
    </html>
    <!-- END OF PAGE-->
    <!-- ====================================================================================== -->
  </xsl:template>

  <!-- =========================================== -->
  <!-- Template: GroupTag -->
  <!-- This template reads all the Eurosoft_ tags to
       output each device.-->
  <!-- =========================================== -->
  <xsl:template name="GroupTag">
    <!-- Create the table content -->
    <!-- Create a row in the table for the group name. -->
    <xsl:variable name="Tag" select="local-name()" />
    <div class="DeviceDiv">
      <div class="PaddingDiv">
        <div class="Group">
          Group <xsl:value-of select="@Group"/>
        </div>
        <!-- These other cells are for formatting and layout only.-->
        <div class="SubDevice"></div>
        <div class="AttribName"></div>
        <div class="AttribID"></div>
        <div class="AttribValue"></div>
      </div>

      <!-- Check each of the sub tags to output.-->
      <xsl:for-each select="./*">
        <xsl:call-template name="DeviceTag"/>
      </xsl:for-each>
    </div>
  </xsl:template>

  <!-- =========================================== -->
  <!-- Template: DeviceTag -->
  <!-- This template reads the attributes associated
       with a device for output.-->
  <!-- =========================================== -->
  <xsl:template name="DeviceTag">
    <div class="PaddingDiv">
      <div class="Group"></div>
      <div class="SubDevice">Device <xsl:value-of select="@ID"/></div>
      <!-- Output empty Divs for formatting-->
      <div class="AttribName"></div>
      <div class="AttribID"></div>
      <div class="AttribValue"></div>
    </div>
    <!-- Check each of the sub tags to output.-->
    <xsl:for-each select="./*">
      <!-- The next tag should be the component tag. -->
      <xsl:if test="local-name() = 'Component'">
        <!-- We need to add a Sub device line -->
        <xsl:call-template name="SubDeviceTag"/>      
      </xsl:if>
      <!-- Otherwise-->
      <xsl:if test="local-name() = 'Attribute'">
        <xsl:call-template name="Attribute"/>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <!-- =========================================== -->
  <!-- Template: SubDeviceTag -->
  <!-- This template writes the Subdevice number and
       then writes all the sub attributes.-->
  <!-- =========================================== -->
  <xsl:template name="SubDeviceTag">
    <xsl:variable name="Tag" select="local-name()" />
    <div class="PaddingDiv">
      <div class="Group"></div>
      <div class="SubDevice" style="text-indent: 1em;">SubDevice <xsl:value-of select="@ID"/></div>
      <!-- Output empty Divs for formatting-->
      <div class="AttribName"></div>
      <div class="AttribID"></div>
      <div class="AttribValue"></div>
    </div>

    <!-- Output all sub attributes-->
    <xsl:for-each select="./*">
      <xsl:call-template name="Attribute"/>
    </xsl:for-each>
  </xsl:template>

  <!-- =========================================== -->
  <!-- Template: Attribute -->
  <!-- This template a single attribute entry.-->
  <!-- =========================================== -->
  <xsl:template name="Attribute">
    <div class="PaddingDiv">
      <!-- Write the empty Divs for formatting-->
      <div class="Group"></div>
      <div class="SubDevice"></div>
      <!-- Write the cell content -->
      <div class="AttribName"><xsl:value-of select="@Name"/></div>
      <div class="AttribID"><xsl:value-of select="@ID"/></div>
      <div class="AttribValue"><xsl:value-of select="@Value"/></div>
    </div>    
  </xsl:template>
  
</xsl:stylesheet>